# Scratch Tools
A Python package with which to work with Scratch JSON files, from the Creative Computing Lab at the Harvard Graduate School of Education.

## Setup

Make sure you have Python 3.7 or higher. Then install the package by running ```pip install ccl-scratch-tools```.

Check it out on PyPI: [https://pypi.org/project/ccl-scratch-tools/](https://pypi.org/project/ccl-scratch-tools/).

## Documentation

Read the documentation of the package [here](https://ccl-scratch-tools.readthedocs.io/en/latest/).

## Resources
[https://github.com/LLK/scratch-rest-api/wiki/](https://github.com/LLK/scratch-rest-api/wiki/) for API documentation
